@@ -41,8 +41,10 @@ import time
 
 import numpy as np
 import pandas as pd
+import scipy.sparse.csr
 from pandas._testing import assert_frame_equal
 import networkx as nx
+import scipy as sp
 from scipy.sparse import csr_matrix
 
 from esa import SAW, COMError, PowerWorldError, CommandNotRespectedError, \
@@ -475,7 +477,7 @@ class GetKeyFieldListTestCase(unittest.TestCase):
 
         # Key fields have changed for 3 winding transformers between
         # versions.
-        if VERSION in [21, 22]:
+        if VERSION in [21, 22, 23]:
             expected = ['BusIdentifier', 'BusIdentifier:1', 'BusIdentifier:2',
                         'LineCircuit']
         elif VERSION == 17:
@@ -548,7 +550,7 @@ class IdentifyNumericFieldsTestCase(unittest.TestCase):
     # noinspection PyMethodMayBeStatic
     def test_correct(self):
         # Intentionally make the fields out of alphabetical order.
-        if VERSION in [21, 22]:
+        if VERSION in [21, 22, 23]:
             fields = ['LineStatus', 'LockOut', 'LineR', 'LineX', 'BusNum']
             expected = np.array([False, False, True, True, True])
         elif VERSION == 17:
@@ -843,11 +845,13 @@ class FastCATestCase(unittest.TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         cls.saw = SAW(PATH_14, CreateIfNotFound=True)
+        cls.saw2 = SAW(PATH_2000, CreateIfNotFound=True)
 
     @classmethod
     def tearDownClass(cls) -> None:
         # noinspection PyUnresolvedReferences
         cls.saw.exit()
+        cls.saw2.exit()
 
     def test_get_lodf_matrix_default(self):
         """Should return an N*N square matrix
@@ -857,6 +861,12 @@ class FastCATestCase(unittest.TestCase):
         self.assertEqual(lodf.shape[0], lodf.shape[1])
         self.assertEqual(lodf.shape[0], lodf.shape[0])
 
+    def test_get_lodf_matrix_large(self):
+        """Should return a sparse matrix
+        """
+        lodf, isl = self.saw2.get_lodf_matrix()
+        self.assertIsInstance(lodf, sp.sparse.csr.csr_matrix)
+
     def test_get_incidence_matrix(self):
         """ Should return an N*M matrix
         """
